import 'package:flutter/material.dart';
import 'package:marscar_controller/pages/home_page.dart';
import 'package:media_kit/media_kit.dart';
import 'package:flutter/services.dart';
import 'package:provider/provider.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  MediaKit.ensureInitialized();

  SystemChrome.setPreferredOrientations([
    DeviceOrientation.portraitUp,
  ]);

  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (context) => GlobalSettingState(),
      child: MaterialApp(
        title: 'MarsCar Controller',
        theme: ThemeData(
          colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
        ),
        home: HomePage()
      ),
    );
  }
}

class GlobalSettingState extends ChangeNotifier {
  String cameraIP = '';
  void setCameraIP(String ip) {
    cameraIP = ip;
    notifyListeners();
  }

  String carIP = '';
  void setCarIP(String ip) {
    carIP = ip;
    notifyListeners();
  }
}